# cloudmersive-nlp-api-client

CloudmersiveNlpApiClient - the Ruby gem for the nlpapiv2

The powerful Natural Language Processing APIs (v2) let you perform part of speech tagging, entity identification, sentence parsing, and much more to help you understand the meaning of unstructured text.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: v1
- Package version: 3.0.3
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build cloudmersive-nlp-api-client.gemspec
```

Then either install the gem locally:

```shell
gem install ./cloudmersive-nlp-api-client-3.0.3.gem
```
(for development, run `gem install --dev ./cloudmersive-nlp-api-client-3.0.3.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'cloudmersive-nlp-api-client', '~> 3.0.3'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'cloudmersive-nlp-api-client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'cloudmersive-nlp-api-client'

# Setup authorization
CloudmersiveNlpApiClient.configure do |config|
  # Configure API key authorization: Apikey
  config.api_key['Apikey'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Apikey'] = 'Bearer'
end

api_instance = CloudmersiveNlpApiClient::AnalyticsApi.new

input = CloudmersiveNlpApiClient::HateSpeechAnalysisRequest.new # HateSpeechAnalysisRequest | Input hate speech analysis request


begin
  #Perform Hate Speech Analysis and Detection on Text
  result = api_instance.analytics_hate_speech(input)
  p result
rescue CloudmersiveNlpApiClient::ApiError => e
  puts "Exception when calling AnalyticsApi->analytics_hate_speech: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.cloudmersive.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CloudmersiveNlpApiClient::AnalyticsApi* | [**analytics_hate_speech**](docs/AnalyticsApi.md#analytics_hate_speech) | **POST** /nlp-v2/analytics/hate-speech | Perform Hate Speech Analysis and Detection on Text
*CloudmersiveNlpApiClient::AnalyticsApi* | [**analytics_profanity**](docs/AnalyticsApi.md#analytics_profanity) | **POST** /nlp-v2/analytics/profanity | Perform Profanity and Obscene Language Analysis and Detection on Text
*CloudmersiveNlpApiClient::AnalyticsApi* | [**analytics_sentiment**](docs/AnalyticsApi.md#analytics_sentiment) | **POST** /nlp-v2/analytics/sentiment | Perform Sentiment Analysis and Classification on Text
*CloudmersiveNlpApiClient::AnalyticsApi* | [**analytics_similarity**](docs/AnalyticsApi.md#analytics_similarity) | **POST** /nlp-v2/analytics/similarity | Perform Semantic Similarity Comparison of Two Strings
*CloudmersiveNlpApiClient::AnalyticsApi* | [**analytics_subjectivity**](docs/AnalyticsApi.md#analytics_subjectivity) | **POST** /nlp-v2/analytics/subjectivity | Perform Subjectivity and Objectivity Analysis on Text
*CloudmersiveNlpApiClient::ExtractEntitiesApi* | [**extract_entities_post**](docs/ExtractEntitiesApi.md#extract_entities_post) | **POST** /nlp-v2/extract-entities | Extract entities from string
*CloudmersiveNlpApiClient::LanguageDetectionApi* | [**language_detection_get_language**](docs/LanguageDetectionApi.md#language_detection_get_language) | **POST** /nlp-v2/language/detect | Detect language of text
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_deu_to_eng**](docs/LanguageTranslationApi.md#language_translation_translate_deu_to_eng) | **POST** /nlp-v2/translate/language/deu/to/eng | Translate German to English text with Deep Learning AI
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_eng_to_deu**](docs/LanguageTranslationApi.md#language_translation_translate_eng_to_deu) | **POST** /nlp-v2/translate/language/eng/to/deu | Translate English to German text with Deep Learning AI
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_eng_to_fra**](docs/LanguageTranslationApi.md#language_translation_translate_eng_to_fra) | **POST** /nlp-v2/translate/language/eng/to/fra | Translate English to French text with Deep Learning AI
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_eng_to_rus**](docs/LanguageTranslationApi.md#language_translation_translate_eng_to_rus) | **POST** /nlp-v2/translate/language/eng/to/rus | Translate English to Russian text with Deep Learning AI
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_fra_to_eng**](docs/LanguageTranslationApi.md#language_translation_translate_fra_to_eng) | **POST** /nlp-v2/translate/language/fra/to/eng | Translate French to English text with Deep Learning AI
*CloudmersiveNlpApiClient::LanguageTranslationApi* | [**language_translation_translate_rus_to_eng**](docs/LanguageTranslationApi.md#language_translation_translate_rus_to_eng) | **POST** /nlp-v2/translate/language/rus/to/eng | Translate Russian to English text with Deep Learning AI
*CloudmersiveNlpApiClient::ParseApi* | [**parse_parse_string**](docs/ParseApi.md#parse_parse_string) | **POST** /nlp-v2/parse/tree | Parse string to syntax tree
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_adjectives**](docs/PosTaggerApi.md#pos_tagger_tag_adjectives) | **POST** /nlp-v2/pos/tag/adjectives | Part-of-speech tag a string, filter to adjectives
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_adverbs**](docs/PosTaggerApi.md#pos_tagger_tag_adverbs) | **POST** /nlp-v2/pos/tag/adverbs | Part-of-speech tag a string, filter to adverbs
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_nouns**](docs/PosTaggerApi.md#pos_tagger_tag_nouns) | **POST** /nlp-v2/pos/tag/nouns | Part-of-speech tag a string, filter to nouns
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_pronouns**](docs/PosTaggerApi.md#pos_tagger_tag_pronouns) | **POST** /nlp-v2/pos/tag/pronouns | Part-of-speech tag a string, filter to pronouns
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_sentence**](docs/PosTaggerApi.md#pos_tagger_tag_sentence) | **POST** /nlp-v2/pos/tag/sentence | Part-of-speech tag a string
*CloudmersiveNlpApiClient::PosTaggerApi* | [**pos_tagger_tag_verbs**](docs/PosTaggerApi.md#pos_tagger_tag_verbs) | **POST** /nlp-v2/pos/tag/verbs | Part-of-speech tag a string, filter to verbs
*CloudmersiveNlpApiClient::RephraseApi* | [**rephrase_english_rephrase_sentence_by_sentence**](docs/RephraseApi.md#rephrase_english_rephrase_sentence_by_sentence) | **POST** /nlp-v2/rephrase/rephrase/eng/by-sentence | Rephrase, paraphrase English text sentence-by-sentence using Deep Learning AI
*CloudmersiveNlpApiClient::SegmentationApi* | [**segmentation_get_sentences**](docs/SegmentationApi.md#segmentation_get_sentences) | **POST** /nlp-v2/segmentation/sentences | Extract sentences from string
*CloudmersiveNlpApiClient::SegmentationApi* | [**segmentation_get_words**](docs/SegmentationApi.md#segmentation_get_words) | **POST** /nlp-v2/segmentation/words | Get words in input string
*CloudmersiveNlpApiClient::SpellcheckApi* | [**spellcheck_check_sentence**](docs/SpellcheckApi.md#spellcheck_check_sentence) | **POST** /nlp-v2/spellcheck/check/sentence | Check if sentence is spelled correctly
*CloudmersiveNlpApiClient::SpellcheckApi* | [**spellcheck_correct_json**](docs/SpellcheckApi.md#spellcheck_correct_json) | **POST** /nlp-v2/spellcheck/check/word | Find spelling corrections


## Documentation for Models

 - [CloudmersiveNlpApiClient::CheckSentenceRequest](docs/CheckSentenceRequest.md)
 - [CloudmersiveNlpApiClient::CheckSentenceResponse](docs/CheckSentenceResponse.md)
 - [CloudmersiveNlpApiClient::CheckWordRequest](docs/CheckWordRequest.md)
 - [CloudmersiveNlpApiClient::CheckWordResponse](docs/CheckWordResponse.md)
 - [CloudmersiveNlpApiClient::CorrectWordInSentence](docs/CorrectWordInSentence.md)
 - [CloudmersiveNlpApiClient::Entity](docs/Entity.md)
 - [CloudmersiveNlpApiClient::ExtractEntitiesRequest](docs/ExtractEntitiesRequest.md)
 - [CloudmersiveNlpApiClient::ExtractEntitiesResponse](docs/ExtractEntitiesResponse.md)
 - [CloudmersiveNlpApiClient::GetWordsRequest](docs/GetWordsRequest.md)
 - [CloudmersiveNlpApiClient::GetWordsResponse](docs/GetWordsResponse.md)
 - [CloudmersiveNlpApiClient::HateSpeechAnalysisRequest](docs/HateSpeechAnalysisRequest.md)
 - [CloudmersiveNlpApiClient::HateSpeechAnalysisResponse](docs/HateSpeechAnalysisResponse.md)
 - [CloudmersiveNlpApiClient::LanguageDetectionRequest](docs/LanguageDetectionRequest.md)
 - [CloudmersiveNlpApiClient::LanguageDetectionResponse](docs/LanguageDetectionResponse.md)
 - [CloudmersiveNlpApiClient::LanguageTranslationRequest](docs/LanguageTranslationRequest.md)
 - [CloudmersiveNlpApiClient::LanguageTranslationResponse](docs/LanguageTranslationResponse.md)
 - [CloudmersiveNlpApiClient::ParseRequest](docs/ParseRequest.md)
 - [CloudmersiveNlpApiClient::ParseResponse](docs/ParseResponse.md)
 - [CloudmersiveNlpApiClient::PosRequest](docs/PosRequest.md)
 - [CloudmersiveNlpApiClient::PosResponse](docs/PosResponse.md)
 - [CloudmersiveNlpApiClient::PosSentence](docs/PosSentence.md)
 - [CloudmersiveNlpApiClient::PosTaggedWord](docs/PosTaggedWord.md)
 - [CloudmersiveNlpApiClient::ProfanityAnalysisRequest](docs/ProfanityAnalysisRequest.md)
 - [CloudmersiveNlpApiClient::ProfanityAnalysisResponse](docs/ProfanityAnalysisResponse.md)
 - [CloudmersiveNlpApiClient::RephraseRequest](docs/RephraseRequest.md)
 - [CloudmersiveNlpApiClient::RephraseResponse](docs/RephraseResponse.md)
 - [CloudmersiveNlpApiClient::RephrasedSentence](docs/RephrasedSentence.md)
 - [CloudmersiveNlpApiClient::RephrasedSentenceOption](docs/RephrasedSentenceOption.md)
 - [CloudmersiveNlpApiClient::SentenceSegmentationRequest](docs/SentenceSegmentationRequest.md)
 - [CloudmersiveNlpApiClient::SentenceSegmentationResponse](docs/SentenceSegmentationResponse.md)
 - [CloudmersiveNlpApiClient::SentimentAnalysisRequest](docs/SentimentAnalysisRequest.md)
 - [CloudmersiveNlpApiClient::SentimentAnalysisResponse](docs/SentimentAnalysisResponse.md)
 - [CloudmersiveNlpApiClient::SimilarityAnalysisRequest](docs/SimilarityAnalysisRequest.md)
 - [CloudmersiveNlpApiClient::SimilarityAnalysisResponse](docs/SimilarityAnalysisResponse.md)
 - [CloudmersiveNlpApiClient::SubjectivityAnalysisRequest](docs/SubjectivityAnalysisRequest.md)
 - [CloudmersiveNlpApiClient::SubjectivityAnalysisResponse](docs/SubjectivityAnalysisResponse.md)
 - [CloudmersiveNlpApiClient::WordPosition](docs/WordPosition.md)


## Documentation for Authorization


### Apikey

- **Type**: API key
- **API key parameter name**: Apikey
- **Location**: HTTP header

